mailr6592 - /1.3/generic_fns/sequence.py


Others Months | Index by Date | Thread Index
>>   [Date Prev] [Date Next] [Thread Prev] [Thread Next]

Header


Content

Posted by edward on June 29, 2008 - 15:55:
Author: bugman
Date: Sun Jun 29 15:18:09 2008
New Revision: 6592

URL: http://svn.gna.org/viewcvs/relax?rev=6592&view=rev
Log:
Fixed the spin loop call in the copy() function.


Modified:
    1.3/generic_fns/sequence.py

Modified: 1.3/generic_fns/sequence.py
URL: 
http://svn.gna.org/viewcvs/relax/1.3/generic_fns/sequence.py?rev=6592&r1=6591&r2=6592&view=diff
==============================================================================
--- 1.3/generic_fns/sequence.py (original)
+++ 1.3/generic_fns/sequence.py Sun Jun 29 15:18:09 2008
@@ -64,8 +64,8 @@
     if exists_mol_res_spin_data(pipe_to):
         raise RelaxSequenceError
 
-    # Loop over the spins.
-    for spin, mol_name, res_num, res_name in spin_loop(full_info=True):
+    # Loop over the spins of the pipe_from data pipe.
+    for spin, mol_name, res_num, res_name in spin_loop(pipe=pipe_from, 
full_info=True):
         # Generate the new sequence.
         generate(mol_name, res_num, res_name, spin.num, spin.name, pipe_to)
 




Related Messages


Powered by MHonArc, Updated Sun Jun 29 16:00:20 2008